@@ -53,14 +53,12 @@ class Server():
         try:
             # 优先使用Python内置方法创建目录（更跨平台且安全）
             if not self.__directory_exists(home):
-                log.info(f"开始创建主目录: {home}")
                 self.__create_directory(home)
 
             # 验证目录是否成功创建
             if not self.__directory_exists(home):
                 raise RuntimeError(f"主目录创建后验证失败: {home}不存在")
 
-            log.info(f"主目录初始化成功: {home}")
             return home
 
         except Exception as e:
@@ -71,7 +69,7 @@ class Server():
     def __validate_platform(self) -> None:
         """验证操作系统是否为Linux，不支持则抛出异常"""
         if self.__platform == "Linux":
-            log.info(f"当前操作系统: {self.__platform} (支持)")
+            pass
         else:
             raise RuntimeError(
                 f"不支持的操作系统: {self.__platform}，仅支持Linux"
@@ -105,7 +103,6 @@ class Server():
         try:
             # 执行命令，捕获 stdout 和 stderr
             # 使用shell=True时command可为字符串，否则应为列表
-            log.info(f"执行命令: {command}")
             shell = isinstance(command, str)
             result = subprocess.run(
                 command,
@@ -156,7 +153,6 @@ class Server():
             捕获Git命令执行异常和其他通用异常，并记录警告日志
         """
         try:
-            log.info(f"开始克隆仓库: {repo_url} 分支: {branch} 到路径: {dest_path}")
             # 检查目标路径是否已存在
             if os.path.exists(dest_path):
                 # 检查是否为已存在的Git仓库
@@ -174,7 +170,6 @@ class Server():
                 os.makedirs(parent_dir, exist_ok=True)
 
             # 执行克隆操作
-            log.info(f"开始克隆仓库: {repo_url} 分支: {branch} 到路径: {dest_path}")
             repo = Repo.clone_from(
                 url=repo_url,
                 to_path=dest_path,
@@ -194,12 +189,6 @@ class Server():
                     f"实际分支: {current_branch}, 预期分支: {branch}"
                 )
                 return False
-
-            # 所有验证通过
-            log.info(
-                f"克隆成功 - "
-                f"目标路径: {dest_path}, 当前分支: {current_branch}"
-            )
             return True
 
         except GitCommandError as e:
@@ -236,7 +225,6 @@ class Server():
         返回:
             符合条件的文件路径或名称列表（去重后按查找顺序排列）
         """
-        log.info(f"开始查找目录: {root_dir} 下符合条件的文件")
         # 处理排除列表（转为集合提高查找效率）
         exclude_dirs_set: Set[str] = set(exclude_dirs) if exclude_dirs else set()
         exclude_files_set: Set[str] = set(exclude_files) if exclude_files else set()
@@ -317,7 +305,6 @@ class Server():
         返回:
             解析后的JSON数据（字典、列表等），如果发生错误则返回None
         """
-        log.info(f"开始读取JSON文件: {file_path}")
         # 检查文件是否存在
         if not os.path.exists(file_path):
             log.warning(f"错误: 文件不存在 - {file_path}")
@@ -360,7 +347,6 @@ class Server():
         返回:
             找到的文件的绝对路径；如果未找到或发生错误则返回None
         """
-        log.info(f"开始查找文件 - {file_name}，目录: {dest_dir}")
         # 验证目标目录是否存在且是有效目录
         if not os.path.isdir(dest_dir):
             return None
